summaryrefslogtreecommitdiffstats
path: root/src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit27648a99ce3a8a1e498828f1fc93cbd6b3476a91 (patch)
tree09939e827c3467356b78fce055d5b2826a832ae5 /src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp
parent99e44ac443d2590ecdeb0da46608a0a537177fd7 (diff)
downloadkvirc-27648a99ce3a8a1e498828f1fc93cbd6b3476a91.tar.gz
kvirc-27648a99ce3a8a1e498828f1fc93cbd6b3476a91.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kvirc@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp')
-rw-r--r--src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp b/src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp
index 0014743..4cf0cbc 100644
--- a/src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp
+++ b/src/kvirc/kvs/kvi_kvs_parser_specialcommands.cpp
@@ -329,7 +329,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandClass()
that can be used to sign the parameters that the function expects;
it acts as a programmer reminder or comment and it has no other
meaning in KVIrc scripting. The <parameter reminder> respects the syntax
- of an expression, so it is terminated by a closed tqparenthesis.
+ of an expression, so it is terminated by a closed parenthesis.
It's rather dangerous to use this command inside an object
function handler: if the class definition <class> was already
existing and it is a tqparent of the object's class, you might
@@ -376,7 +376,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandClass()
if(KVSP_curCharUnicode != '(')
{
- error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where an open tqparenthesis was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where an open parenthesis was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
@@ -627,8 +627,8 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandWhile()
if(KVSP_curCharUnicode != '(')
{
- warning(KVSP_curCharPointer,__tr2qs("The while command needs an expression enclosed in tqparenthesis"));
- error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where an open tqparenthesis was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
+ warning(KVSP_curCharPointer,__tr2qs("The while command needs an expression enclosed in parenthesis"));
+ error(KVSP_curCharPointer,__tr2qs("Found character %q (tqunicode %x) where an open parenthesis was expected"),KVSP_curCharPointer,KVSP_curCharUnicode);
return 0;
}
@@ -756,7 +756,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandDo()
if(KVSP_curCharUnicode != '(')
{
- warning(KVSP_curCharPointer,__tr2qs("The 'while' block of the 'do' command needs an expression enclosed in tqparenthesis"));
+ warning(KVSP_curCharPointer,__tr2qs("The 'while' block of the 'do' command needs an expression enclosed in parenthesis"));
errorBadChar(KVSP_curCharPointer,'(',"do");
if(i)delete i;
return 0;
@@ -822,7 +822,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandIf()
if(KVSP_curCharUnicode != '(')
{
- warning(KVSP_curCharPointer,__tr2qs("The 'if' command needs an expression enclosed in tqparenthesis"));
+ warning(KVSP_curCharPointer,__tr2qs("The 'if' command needs an expression enclosed in parenthesis"));
errorBadChar(KVSP_curCharPointer,'(',"if");
return 0;
}
@@ -967,7 +967,7 @@ bool KviKvsParser::skipToEndOfForControlBlock()
return false;
break;
//case '\n':
// that's ok.. it may have a tqparenthesis on the next line
//KVSP_skipChar;
//break;
default:
@@ -1012,7 +1012,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandFor()
if(KVSP_curCharUnicode != '(')
{
- warning(KVSP_curCharPointer,__tr2qs("The 'for' command needs an expression enclosed in tqparenthesis"));
+ warning(KVSP_curCharPointer,__tr2qs("The 'for' command needs an expression enclosed in parenthesis"));
errorBadChar(KVSP_curCharPointer,'(',"for");
return 0;
}
@@ -1178,7 +1178,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandForeach()
if(KVSP_curCharUnicode != '(')
{
- warning(KVSP_curCharPointer,__tr2qs("The 'foreach' command needs an expression enclosed in tqparenthesis"));
+ warning(KVSP_curCharPointer,__tr2qs("The 'foreach' command needs an expression enclosed in parenthesis"));
errorBadChar(KVSP_curCharPointer,'(',"foreach");
return 0;
}
@@ -1362,7 +1362,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandSwitch()
if(KVSP_curCharUnicode != '(')
{
- warning(KVSP_curCharPointer,__tr2qs("The 'switch' command needs an expression enclosed in tqparenthesis"));
+ warning(KVSP_curCharPointer,__tr2qs("The 'switch' command needs an expression enclosed in parenthesis"));
errorBadChar(KVSP_curCharPointer,'(',"switch");
return 0;
}
@@ -1928,7 +1928,7 @@ KviKvsTreeNodeCommand * KviKvsParser::parseSpecialCommandDefpopup()
if(KVSP_curCharUnicode != '(')
{
- warning(KVSP_curCharPointer,__tr2qs("The 'defpopup' command needs an expression enclosed in tqparenthesis"));
+ warning(KVSP_curCharPointer,__tr2qs("The 'defpopup' command needs an expression enclosed in parenthesis"));
errorBadChar(KVSP_curCharPointer,'(',"defpopup");
return 0;
}
@@ -967,7 +967,7 @@ bool KviKvsParser::skipToEndOfForControlBlock()
break;
//case '\n':
- // that's ok.. it may have a tqparenthesis on the next line
+ // that's ok.. it may have a parenthesis on the next line
//KVSP_skipChar;
//break;